@@ -1,19 +1,45 @@
-package Clustericious::Command::hypnotoad;
+=head1 NAME
 
-use strict;
-use warnings;
+Clustericious::Command::Hypnotoad
+
+=head1 DESCRIPTION
+
+Start a hypnotoad webserver.
+
+Configuration for the server is taken directly from the
+"hypnotoad" entry in the config file, and turned into
+a config file for hypnotoad.  The location of the file
+can be controllled by setting HYPNOTOAD_CONFIG.
+
+=head1 EXAMPLE
+
+ start_mode : "hypnotoad"
+ hypnotoad:
+    workers : 1
+    listen : [ "http://*:3000" ]
+    inactivity_timeout : 50
+    pid_file : /tmp/minionrelay.pid
+
+
+=head1 SEE ALSO
+
+Mojo::Server::Hypnotoad
+
+=cut
+
+package Clustericious::Command::hypnotoad;
 use Clustericious::Log;
+
 use Clustericious::App;
 use Clustericious::Config;
 use Mojo::Server::Hypnotoad;
 use Data::Dumper;
 use File::Slurp qw/slurp/;
 use Cwd qw/getcwd abs_path/;
-use base 'Clustericious::Command';
-
-# ABSTRACT: Clustericious command to stat Hypnotoad
-our $VERSION = '0.9940_04'; # VERSION
+use base 'Mojolicious::Command';
 
+use strict;
+use warnings;
 
 __PACKAGE__->attr(description => "Start a hypnotad web server.\n");
 
@@ -31,7 +57,7 @@ sub run {
     DEBUG "Config : $conf_string";
     my $exe = $0;
     DEBUG "Running hypnotoad : $exe";
-    $ENV{HYPNOTOAD_EXE} = "$0";
+    $ENV{HYPNOTOAD_EXE} = "$0 hypnotoad";
     my $sentinel = '/no/such/file/because/these/are/deprecated';
     if ( $ENV{HYPNOTOAD_CONFIG} && $ENV{HYPNOTOAD_CONFIG} ne $sentinel ) {
         WARN "HYPNOTOAD_CONFIG value $ENV{HYPNOTOAD_CONFIG} will be ignored";
@@ -55,7 +81,6 @@ sub run {
             }
         }
         my $toad = Mojo::Server::Hypnotoad->new;
-        $ENV{CLUSTERICIOUS_COMMAND_NAME} = 'hypnotoad';
         $toad->run($exe);
         WARN "hypnotoad exited";
         exit;
@@ -66,68 +91,3 @@ sub run {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::Command::hypnotoad - Clustericious command to stat Hypnotoad
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
-in your application configuration (C<~/etc/YourApp.conf>)
-
- ---
- start_mode : "hypnotoad"
- hypnotoad:
-    workers : 1
-        listen :
-            - "http://*:3000"
-    inactivity_timeout : 50
-    pid_file : /tmp/minionrelay.pid
-
-then at the command line:
-
- % yourapp start
-
-=head1 DESCRIPTION
-
-Start a hypnotoad web server.
-
-Configuration for the server is taken directly from the
-"hypnotoad" entry in the config file, and turned into
-a config file for hypnotoad.
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
-=head1 SEE ALSO
-
-L<Clustericious>
-L<Mojo::Server::Hypnotoad>,
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
