@@ -1,19 +1,55 @@
-package Clustericious::Command::start;
+=head1 NAME
 
-use strict;
-use warnings;
+Clustericious::Command::start
+
+=head1 DESCRIPTION
+
+Start a daemon using the config file and the start_mode.
+
+=head1 EXAMPLE
+
+For hypnotoad, the config file should
+contain "daemonize" and "pid" keys, e.g. :
+
+   ---
+   start_mode : hypnotoad
+   hypnotoad :
+      pid      : /tmp/restmd.pid
+      [...]
+      env      :
+        foo : bar
+
+The above configuration will will cause "app start"
+to be equivalent to
+
+  foo=bar MyApp.pl hypnotoad -pid /tmp/restmd.pid [..]
+
+In other words, keys and values in the configuration file become
+options preceded by double dashes.
+
+If a key has a single dash, it is sent as is (with no double dash).
+
+The special value "null" means don't send an argument to the
+command line option.
+
+The special label "env" is an optional hash of environment variables
+to set before starting the command.
+
+=cut
+
+package Clustericious::Command::start;
 use Clustericious::Log;
 use File::Slurp qw/slurp/;
 use List::MoreUtils qw/mesh/;
 use File::Path qw/mkpath/;
 use File::Basename qw/dirname/;
+
 use Clustericious::App;
 use Clustericious::Config;
-use Mojo::Base 'Clustericious::Command';
-
-# ABSTRACT: Clustericious command to start a Clustericious application
-our $VERSION = '0.9940_04'; # VERSION 
+use Mojo::Base 'Mojolicious::Command';
 
+use strict;
+use warnings;
 
 has description => <<EOT;
 Start a daemon using the config file.
@@ -28,7 +64,6 @@ EOT
 
 sub run {
     my $self     = shift;
-    exit 2 unless $self->app->sanity_check;
     my @args = @_ ? @_ : @ARGV;
     my $app  = $ENV{MOJO_APP};
     my $conf     = Clustericious::Config->new( $app );
@@ -81,82 +116,3 @@ sub run {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::Command::start - Clustericious command to start a Clustericious application
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
-In your MyApp.conf:
-
- ---
- start_mode: hypnotoad
- hypnotoad:
-   pid: /tmp/restmd.pid
-   [...]
-   env:
-     foo: bar
-
-Then on the command line
-
- % myapp start
-
-Which is equivalent to
-
- % foo=bar myapp hypnotoad --pid /tmp/restmd.pid [..]
-
-=head1 DESCRIPTION
-
-Start a daemon using the config file and the start_mode.
-
-Keys and values in the configuration file become
-options preceded by double dashes.
-
-If a key has a single dash, it is sent as is (with no double dash).
-
-The special value C<null> means don't send an argument to the
-command line option.
-
-The special label C<env> is an optional hash of environment variables
-to set before starting the command.
-
-=head1 NAME
-
-Clustericious::Command::start - Clustericious command to start a Clustericious application
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
-=head1 SEE ALSO
-
-L<Clustericious>,
-L<Clustericious::Command::hypnotoad>
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
